@@ -26,7 +26,8 @@ use Test::MockObject::Extends;
 use TestUtils qw(read_client_properties);
 
 @ISA       = qw(Exporter);
-@EXPORT_OK = qw(get_test_client get_test_mcc_client get_test_client_no_auth);
+@EXPORT_OK
+  = qw(get_test_client get_test_manager_account_client get_test_client_no_auth);
 
 sub get_test_client {
   my $api_version = shift;
@@ -45,18 +46,19 @@ sub get_test_client {
   return $client;
 }
 
-sub get_test_mcc_client {
+sub get_test_manager_account_client {
   my $api_version = shift;
 
   my $client = get_test_client($api_version);
 
   my $client_properties = read_client_properties();
 
-  my $mcc_client_id = $client_properties->getProperty('mccClientId');
+  my $manager_account_client_id
+    = $client_properties->getProperty('managerAccountClientId');
 
-  die "No MCC client ID found" unless $mcc_client_id;
+  die "No manager account client ID found" unless $manager_account_client_id;
 
-  $client->set_client_id($mcc_client_id);
+  $client->set_client_id($manager_account_client_id);
 }
 
 sub get_test_client_no_auth {
